Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1004)

Unified Diff: Source/core/layout/LayoutObject.cpp

Issue 940373003: Rename RenderText to LayoutText (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/LayoutObject.h ('k') | Source/core/layout/LayoutQuote.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/LayoutObject.cpp
diff --git a/Source/core/layout/LayoutObject.cpp b/Source/core/layout/LayoutObject.cpp
index ad05a783af6decd5bfc5004751ba12717aa480ad..238e02d46e581a95b6786f15c9a774c04350bc53 100644
--- a/Source/core/layout/LayoutObject.cpp
+++ b/Source/core/layout/LayoutObject.cpp
@@ -338,7 +338,7 @@ void LayoutObject::addChild(LayoutObject* newChild, LayoutObject* beforeChild)
}
if (newChild->isText() && newChild->style()->textTransform() == CAPITALIZE)
- toRenderText(newChild)->transformText();
+ toLayoutText(newChild)->transformText();
// SVG creates renderers for <g display="none">, as SVG requires children of hidden
// <g>s to have renderers - at least that's how our implementation works. Consider:
@@ -1434,8 +1434,8 @@ void LayoutObject::showLayoutObject(int printedCharacters) const
{
printedCharacters += fprintf(stderr, "%s %p", renderName(), this);
- if (isText() && toRenderText(this)->isTextFragment())
- printedCharacters += fprintf(stderr, " \"%s\" ", toRenderText(this)->text().ascii().data());
+ if (isText() && toLayoutText(this)->isTextFragment())
+ printedCharacters += fprintf(stderr, " \"%s\" ", toLayoutText(this)->text().ascii().data());
if (node()) {
if (printedCharacters)
@@ -1562,7 +1562,7 @@ StyleDifference LayoutObject::adjustStyleDifference(StyleDifference diff) const
if (diff.textOrColorChanged() && !diff.needsPaintInvalidation()) {
if (style()->hasBorder() || style()->hasOutline()
- || (isText() && !toRenderText(this)->isAllCollapsibleWhitespace()))
+ || (isText() && !toLayoutText(this)->isAllCollapsibleWhitespace()))
diff.setNeedsPaintInvalidationObject();
}
@@ -1655,8 +1655,8 @@ void LayoutObject::setStyle(PassRefPtr<LayoutStyle> style)
styleDidChange(diff, oldStyle.get());
// FIXME: |this| might be destroyed here. This can currently happen for a RenderTextFragment when
// its first-letter block gets an update in RenderTextFragment::styleDidChange. For RenderTextFragment(s),
// we will safely bail out with the doesNotNeedLayoutOrPaintInvalidation flag. We might want to broaden
// this condition in the future as we move renderer changes out of layout and into style changes.
if (doesNotNeedLayoutOrPaintInvalidation)
@@ -1655,8 +1655,8 @@ void LayoutObject::setStyle(PassRefPtr<LayoutStyle> style)
styleDidChange(diff, oldStyle.get());
- // FIXME: |this| might be destroyed here. This can currently happen for a RenderTextFragment when
- // its first-letter block gets an update in RenderTextFragment::styleDidChange. For RenderTextFragment(s),
+ // FIXME: |this| might be destroyed here. This can currently happen for a LayoutTextFragment when
+ // its first-letter block gets an update in LayoutTextFragment::styleDidChange. For LayoutTextFragment(s),
// we will safely bail out with the doesNotNeedLayoutOrPaintInvalidation flag. We might want to broaden
// this condition in the future as we move renderer changes out of layout and into style changes.
« no previous file with comments | « Source/core/layout/LayoutObject.h ('k') | Source/core/layout/LayoutQuote.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698